==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-divider.dart <==
/*
Description:
A divider tool that creates a horizontal lined divison or seperation.
Can be used to seperate list elements in a List View or create divisions on a page.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-divider.dart';

Usage:
- Defining the object for Divider

    CustomDividerParameters dividerParameters = new CustomDividerParameters(
        height: 1, thickness: 2, indent: 1, endIndent: 1, color: Colors.red);

- Object call for the widget

    CustomDivider(dividerParameters)
    
Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' as cons;

Widget CustomDivider(CustomDividerParameters dividerParams) {
  // Incase user doesn't pass any parameters
  if (dividerParams == null) {
    return Divider(
      height: cons.heightTwentyPixel,
      thickness: cons.thicknesssTwoPixel,
      indent: cons.indentOnePixel,
      endIndent: cons.endIndentOnePixel,
      color: MediumGreyThemeData().highlightColor,
    );
  } else {
    // Incase user passes all or limited number of parameters
    return Divider(
      height: (dividerParams.height == null)
          ? cons.heightTwentyPixel
          : dividerParams.height,
      thickness: (dividerParams.thickness == null)
          ? cons.thicknesssTwoPixel
          : dividerParams.thickness,
      indent: (dividerParams.indent == null)
          ? cons.indentOnePixel
          : dividerParams.indent,
      endIndent: (dividerParams.endIndent == null)
          ? cons.endIndentOnePixel
          : dividerParams.endIndent,
      color: (dividerParams.color == null)
          ? MediumGreyThemeData().highlightColor
          : dividerParams.color,
    );
  }
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-divider.dart <==
/*
Description:
A divider tool that creates a horizontal lined divison or seperation.
Can be used to seperate list elements in a List View or create divisions on a page.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-divider.dart';

Usage:
- Defining the object for Divider

    CustomDividerParameters dividerParameters = new CustomDividerParameters(
        height: 1, thickness: 2, indent: 1, endIndent: 1, color: Colors.red);

- Object call for the widget

    customDivider(dividerParameters)
    
Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'theme.dart';
import 'widget-classesUsed.dart';
import 'consts.dart' as cons;

Widget customDivider(CustomDividerParameters dividerparams) {
  // Incase user doesn't pass any parameters
  if (dividerparams == null) {
    return Divider(
      height: cons.heightTwentyPixel,
      thickness: cons.thicknesssTwoPixel,
      indent: cons.indentOnePixel,
      endIndent: cons.endIndentOnePixel,
      color: mediumGreyThemeData().highlightColor,
    );
  } else {
    // Incase user passes all or limited number of parameters
    return Divider(
      height: (dividerparams.height == null)
          ? cons.heightTwentyPixel
          : dividerparams.height,
      thickness: (dividerparams.thickness == null)
          ? cons.thicknesssTwoPixel
          : dividerparams.thickness,
      indent: (dividerparams.indent == null)
          ? cons.indentOnePixel
          : dividerparams.indent,
      endIndent: (dividerparams.endIndent == null)
          ? cons.endIndentOnePixel
          : dividerparams.endIndent,
      color: (dividerparams.color == null)
          ? mediumGreyThemeData().highlightColor
          : dividerparams.color,
    );
  }
}
